_name_map = {
    "age": "Age",
    "albumin": "Albumin",
    "alt": "ALT",
    "ast": "AST",
    "bonet": "T-score",
    "bonez": "Z-score",
    "bparmc": "팔둘레",
    "bmi": "BMI",
    "bun": "BUN",
    "creatine": "Creatine",
    "crp": "CRP",
    "fef25": "FEF25",
    "fev1": "FEV1",
    "fvc": "FVC",
    # "gripl1": "",
    "gripr1": "악력",
    # "grwhich": "",
    "hb": "Hb",
    "hct": "Hct",
    "hdl": "HDL",
    "hba1c": "HbA1C",
    "glu0": "혈당",
    "height": "키",
    "hip": "엉덩이 둘레",
    "waist": "허리둘레",
    "labi": "ABI(왼쪽)",
    "rabi": "ABI(오른쪽)",
    "ldl": "LDL",
    "mch": "MCH",
    "mchc": "MCHC",
    "mcv": "MCV",
    "muscle": "근육량",
    "plat": "PLT",
    "pulse": "맥박",
    "r_gtp": "γ-GTP",
    "rbc": "RBC",
    "stiffness": "Stiffness",
    "t_bil": "T.Bilirubin",
    "tchl": "Cholesterol",
    "tg": "TG",
    "u_ket": "U.ketone",
    "u_ph": "U.pH",
    "uricacid": "UA",
    "wbc": "WBC",
    "whr": "WHR",
    "weight": "체중",
    "sinus bradycardia": "sinus brady",
    "ekg": "EKG",
    "code1": "EKG소견",
    "dm": "당뇨",
}

_ekg_map = {
    "RAE": "RAH",
    "LAE": "LAH",
    "LVH by voltage criteria": "LVH",
    "LVH by cornell voltage": "LVH",
    "LVH with strain": "LVH",
    # A.fib.
    "A.fib.": "A fib",
    "A.fib.": "A fib",
    "A fib with controlled VR": "A fib",
    "A fib with rapid VR": "A fib",
    "A fib with slow VR": "A fib",
    "A.fib. With controlled VR": "A fib",
    "A.fib. With rapid VR": "A fib",
    "A.fib. With slow VR": "A fib",
    "A.fib.with marked slow VR": "A fib",
    # premature
    "APC": "premature",
    "APC bigeminy": "premature",
    "APC or JPC": "premature",
    "VPC": "premature",
    "VPC bigeminy": "premature",
    "VPC couplet": "premature",
    "VPC trigeminy": "premature",
    "VPCs quadrigeminy": "premature",
    "VPCs quardisgeminy": "premature",
    # pre-excitation
    "LGL syndrome": "pre-excitation",
    "preexcitation": "pre-excitation",
    "preexitation": "pre-excitation",
    "WPW syndrome": "pre-excitation",
    "WPW sydrome": "pre-excitation",
    "ventricular preexcitation": "pre-excitation",
    "ventricular preexitation": "pre-excitation",
    "ventriculat preexitation": "pre-excitation",
    # MI
    "old MI anteroseptal": "MI",
    "old MI inferior": "MI",
    "old MI lateral": "MI",
    "old MI posterior": "MI",
    "old MI septal": "MI",
    "old MI, anterior": "MI",
    "old MIf, anterior(QS pattern in all of leads V1, V2, and V3)": "MI",
    "old MIf, anterior(QS pattern in all of leads V1-V4 or V1-V5)": "MI",
    "old Mif anteroseptal": "MI",
    "old Mif inferior": "MI",
    "old Mif lateral": "MI",
    "old Mif posterior": "MI",
    "old Mif septal": "MI",
    "myocardial injury anterior wall": "MI",
    "myocardial ischemia": "MI",
    "myocardial ischemia(MIs)(anterior  wall)": "MI",
    "myocardial ischemia(MIs)(anteroseptal wall)": "MI",
    "myocardial ischemia(MIs)(inferior wall)": "MI",
    "MIs(mycardial ischemia)": "MI",
    "MIs(myocardial ischemia)(lateral ischemia)": "MI",
    "Mif(mycardial infarction)": "MI",
    "r/o) old MI(posterior wall)": "MI",
    "r/o) old MIf(myocardial infarction)(posterior wall)": "MI",
    "extensive anterior MI": "MI",
    "extensive anterior MIf": "MI",
    # sinus arrhythmia
    "sinus bradycardia": "sinus arrhythmia",
    "sinus bradycardia with junctional escape beat": "sinus arrhythmia",
    "sinus tachycardia": "sinus arrhythmia",
    "marked sinus bradycardia": "sinus arrhythmia",
    "marked sinus bradycardia with junctional escape beat": "sinus arrhythmia",
    # BBB
    "LBBB": "BBB",
    "RBBB": "BBB",
    "incomplete LBBB": "BBB",
    "incomplete RBBB": "BBB",
    "complete LBBB": "BBB",
    "complete RBBB": "BBB",
    # Heart block
    "AV dissociation": "block",
    "High grade AV block": "block",
    "complete AV block": "block",
    "first degree AV block": "block",
    "secondary degree AV block (type 1 -partial)": "block",
    "Advanced AV block(2:1 conduction)": "block",
    "Complete  heart block with junctinal rhythem": "block",
    "Complete  heart block with junctional rhythem": "block",
    "bifascicular block": "block",
    "left anterior hemiblock": "block",
    "sinoatrial block": "block",
    "sionatrial block": "block",
    "trigascifulcar black(三支阻滞）": "block",
    "LPFB": "block",
    # arrest
    "sinus arrest with escape beats": "arrest",
    "sinus arrest with junctional escape": "arrest",
    "sinus arrest with nunctional escape": "arrest",
    "sinus arrest with wandering atrial pacemaker": "arrest",
    # AFL
    "atrial Filtter with 4:1 conduction": "AFL",
    "atrial filtter with variable conduction": "AFL",
    "atrial flutter with 4:1 conduction": "AFL",
    "atrial flutter with variable conduction": "AFL",
    # ST-T change
    "brugada pattern": "ST-T change",
    "nonspecific ST-T change": "ST-T change",
    "r/o)brugada pattern": "ST-T change",
    # 오타
}
